Module mango_orm::forms [−][src]
Forms.
To create form of search, form of recover password, combine multiple models, etc.
ToForm - Define form settings for models (widgets, html).
Widget - Form controls parameters.
OutputData - Output data for the check() and save() methods.
TransMapWidgetType - For transporting of Widget types map to implementation of methods.
TransMapWidgets - For transporting of Widgets map to implementation of methods.
HtmlControls - Rendering HTML-controls code for Form.
( If necessary, customize the code generation yourself using html and css from Bootstrap, Material Design, etc. )
Modules
Structs
Data structures for inputFile and inputImage widgets.
For transporting of Widgets map to implementation of methods. Hint: <field name, Widget>
Widget. ( Form controls parameters )