Module mango_orm::forms::caching [−][src]
Caching.
Caching information about Forms for speed up work.
Trait:
Caching - Methods caching information about Forms for speed up work.
Methods:
widgets_to_cache - Add map of widgets to cache.
form_wig - Get an widgets map for page template.
form_json - Get Form attributes in Json format for page templates.
form_html - Get Html Form of Model for page templates.
get_cache_data - Get cached Form data.