Module mango_orm::migration [−][src]
Migration of Models to database.
Structs:
ModelState - Creation and updating of a technical database for monitoring the state of models.
Monitor - Creation and updating of a technical database for monitoring the state of models.
Methods:
mango_tech_name - Get the name of the technical database for a project.
refresh - Refresh models state.
napalm - Reorganize databases state.
migrat - Check the changes in the models and (if necessary) apply to the database.